==> pyraptor-0.1.0.tar.gz: pyraptor-0.1.0/README.md <==
Pyraptor
--------

**Pyraptor** for extracting and displaying information from a set of files of the same type; and creating a single CSV file with all the selected information.
	
The information in the files may be in multiple rows:
	
    PC01.txt:
    User=ms123
    Name=Mayra Sanz
    SO=GNU/Linux
    IP=10.226.140.1
	
But, also, the information may be in several columns. It is possible to read data from multiple fields in a single line:
	
    PC01.log:
    User: ms123	    Name: Mayra Sanz
    SO: GNU/Linux   IP: 10.226.140.1		

**Example:** data from the following files...

    PC01.txt:
    User=ms123
    Name=Mayra Sanz
    OS=GNU/Linux
    IP=10.226.140.1

    PC02.txt:
    User=lt001
    Name=Luis Toribio
    OS=GNU/Linux
    IP=10.226.140.2

    PC03.txt:
    User=co205
    Name=Clara Osto
    OS=Win
    IP=10.226.140.3

... You can create a CSV file with the following information:

    users.csv:
    User,Name,OS,IP
    MS123,Mayra Sanz,GNU/linux,10.226.140.1
    LT001,Luis Toribio,GNU/linux,10.226.140.2
    CO205,Clara Osto,Win,10.226.140.3

To achieve this you need to create a template (.rap) with Pyraptor, which is similar to an INI file with the following information:

    users.rap:
    [General]
    description = Get list of users
    extension = txt
    prefix = PC
    output_folder = txt
    input_folder = txt
    output_file = users.csv
    delimiter = ,
    quotechar = "
    include_header = 1
    include_file = 0
    search_multiple = 0
    
    [Fields]
    user = User=
    name = Name=
    os = OS=
    ip = IP=
    
    [Rules]
    rule1 = ('user', 'UPPER')                                       

To create .rap template (If the .rap template exists it is not saved):

	from pyraptor import Pyraptor
	rap1 = Pyraptor()		
	rap1.description = 'Get list of users'
	rap1.extension = 'txt'
	rap1.prefix = 'PC'
	rap1.input_folder = 'txt'
	rap1.output_folder = 'txt'
	rap1.output_file = 'users.csv'
	rap1.delimiter = ','
	rap1.quotechar = '"'
	rap1.include_header = '1'
	rap1.include_file = '0'
	rap1.search_multiple = '0'
	rap1.fields['user'] = 'User='
	rap1.fields['name'] = 'Name='
	rap1.fields['os'] = 'OS='
	rap1.fields['ip'] = 'IP='
	rap1.rules.append(('user', 'UPPER'))
	rap1.Save("users.rap") 	
	del rap1

**Attribute List:**

- description: short descripton of .rap template
- extension: extension of the files to read
- prefix: files must begin with this string
- input_folder: folder of files to read
- output_folder: output folder to save file with result
- output_file: output filename
- delimiter: delimiter character
- quotechar: quote character
- include_header: '0' or '1'
- include_file: '0' or '1'
- search_multiple: '0' or '1'
- fields: dictionary with fieldnames and search string (read template)
- record: dictionary with fieldnames and values (read template)
- rules: list of rules (read template)
- list_files: list of filenames to read (auto)
- errors: list of errors (auto)
- number_errors: number of errors after you open or save a template                 

**Functions available for rules:**
		
- rule1 = (fieldname, 'SUBSTR', postion_initial, lenght)
- rule1 = (fieldname, 'REPLACE', search_string, replace_string)
- rule1 = (fieldname, 'UPPER')
- rule1 = (fieldname, 'LOWER')
- rule1 = (fieldname, 'REVERSE')
- rule1 = (fieldname, 'REMOVE')
- rule1 = (fieldname, 'FIELDISDATA')
- rule1 = (fieldname, 'REMOVEFROM', 'string')
- rule1 = (fieldname, 'REMOVETO', 'string')

Opens template (.rap) and creates (.csv) file from the data read from multiple text files:

	from pyraptor import Pyraptor
	import csv
	rap2 = Pyraptor()
	rap2.Open('users.rap')
	if rap2.number_errors == 0:			
		file_csv = open(rap2.output_file, 'w', newline='')
		csv_output = csv.writer(file_csv, 
					delimiter=rap2.delimiter,
					quotechar=rap2.quotechar, 
					quoting=csv.QUOTE_MINIMAL)
		if rap2.include_header == '1':
			fields_list = rap2.BuildHeader()
			print(fields_list)
			csv_output.writerow(fields_list)
							
		for row in rap2.list_files:
			new_record = rap2.ApplyRules(rap2.BuildRow(row))			
			new_record = list(new_record.values())
			print(new_record)
			csv_output.writerow(new_record)
			print('File 'users.csv' saved.')			
		file_csv.close()			
	else:
		print(rap2.ShowError())
	del rap2

==> pyraptor-0.1.2.tar.gz: pyraptor-0.1.2/README.md <==
Pyraptor
--------

**Pyraptor** for extracting and displaying information from a set of files of the same type; and creating a single CSV file with all the selected information.
	
The information in the files may be in multiple rows:
	
    PC01.txt:
    User=ms123
    Name=Mayra Sanz
    OS=GNU/Linux
    IP=10.226.140.1
	
But, also, the information may be in several columns. It is possible to read data from multiple fields in a single line:
	
    PC01.log:
    User: ms123	    Name: Mayra Sanz
    OS: GNU/Linux   IP: 10.226.140.1		

**Example:** data from the following files...

    PC01.txt:
    User=ms123
    Name=Mayra Sanz
    OS=GNU/Linux
    IP=10.226.140.1

    PC02.txt:
    User=lt001
    Name=Luis Toribio
    OS=GNU/Linux
    IP=10.226.140.2

    PC03.txt:
    User=co205
    Name=Clara Osto
    OS=Win
    IP=10.226.140.3

... You can create a CSV file with the following information:

    users.csv:
    User,Name,OS,IP
    MS123,Mayra Sanz,GNU/linux,10.226.140.1
    LT001,Luis Toribio,GNU/linux,10.226.140.2
    CO205,Clara Osto,Win,10.226.140.3

To achieve this you need to create a template (.rap) with Pyraptor, which is similar to an INI file with the following information:

    users.rap:
    [General]
    description = Get list of users
    extension = txt
    prefix = PC
    output_folder = txt
    input_folder = txt
    output_file = users.csv
    delimiter = ,
    quotechar = "
    include_header = 1
    include_file = 0
    search_multiple = 0
    
    [Fields]
    user = User=
    name = Name=
    os = OS=
    ip = IP=
    
    [Rules]
    rule1 = ('user', 'UPPER')                                       

To create .rap template (If the .rap template exists it is not saved):

	from pyraptor import Pyraptor
	rap1 = Pyraptor()		
	rap1.description = 'Get list of users'
	rap1.extension = 'txt'
	rap1.prefix = 'PC'
	rap1.input_folder = 'txt'
	rap1.output_folder = 'txt'
	rap1.output_file = 'users.csv'
	rap1.delimiter = ','
	rap1.quotechar = '"'
	rap1.include_header = '1'
	rap1.include_file = '0'
	rap1.search_multiple = '0'
	rap1.fields['user'] = 'User='
	rap1.fields['name'] = 'Name='
	rap1.fields['os'] = 'OS='
	rap1.fields['ip'] = 'IP='
	rap1.rules.append(('user', 'UPPER'))
	rap1.Save("users.rap") 	
	del rap1

**Attribute List:**

- description: short descripton of .rap template
- extension: extension of the files to read
- prefix: files must begin with this string
- input_folder: folder of files to read
- output_folder: output folder to save file with result
- output_file: output filename
- delimiter: delimiter character
- quotechar: quote character
- include_header: '0' or '1'
- include_file: '0' or '1'
- search_multiple: '0' or '1'
- fields: dictionary with fieldnames and search string (read template)
- record: dictionary with fieldnames and values (read template)
- rules: list of rules (read template)
- list_files: list of filenames to read (auto)
- errors: list of errors (auto)
- number_errors: number of errors after you open or save a template                 

**Functions available for rules:**
		
- rule1 = (fieldname, 'SUBSTR', postion_initial, lenght)
- rule1 = (fieldname, 'REPLACE', search_string, replace_string)
- rule1 = (fieldname, 'UPPER')
- rule1 = (fieldname, 'LOWER')
- rule1 = (fieldname, 'REVERSE')
- rule1 = (fieldname, 'REMOVE')
- rule1 = (fieldname, 'FIELDISDATA')
- rule1 = (fieldname, 'REMOVEFROM', 'string')
- rule1 = (fieldname, 'REMOVETO', 'string')

Opens template (.rap) and creates (.csv) file from the data read from multiple text files:

	from pyraptor import Pyraptor
	import csv
	rap2 = Pyraptor()
	rap2.Open('users.rap')
	if rap2.number_errors == 0:			
		file_csv = open(rap2.output_file, 'w', newline='')
		csv_output = csv.writer(file_csv, 
					delimiter=rap2.delimiter,
					quotechar=rap2.quotechar, 
					quoting=csv.QUOTE_MINIMAL)
		if rap2.include_header == '1':
			fields_list = rap2.BuildHeader()
			print(fields_list)
			csv_output.writerow(fields_list)
							
		for row in rap2.list_files:
			new_record = rap2.ApplyRules(rap2.BuildRow(row))			
			new_record = list(new_record.values())
			print(new_record)
			csv_output.writerow(new_record)
			print('File 'users.csv' saved.')			
		file_csv.close()			
	else:
		print(rap2.ShowError())
	del rap2
